@@ -198,6 +198,7 @@ def route_to_gdf(
     Returns
     -------
     gdf_edges
+        The ordered edges in the path.
     """
     pairs = zip(route[:-1], route[1:])
     uvk = ((u, v, min(G[u][v].items(), key=lambda i: i[1][weight])[0]) for u, v in pairs)
@@ -316,7 +317,7 @@ def shortest_path(
     Parameters
     ----------
     G
-        Input graph,
+        Input graph.
     orig
         Origin node ID(s).
     dest
@@ -324,7 +325,9 @@ def shortest_path(
     weight
         Edge attribute to minimize when solving shortest path.
     cpus
-        How many CPU cores to use. If None, use all available.
+        How many CPU cores to use if multiprocessing. If None, use all
+        available. If you are multiprocessing, make sure you protect your
+        entry point: see the Python docs for details.
 
     Returns
     -------
@@ -464,10 +467,6 @@ def _verify_edge_attribute(G: nx.MultiDiGraph, attr: str) -> None:
         Input graph.
     attr
         Name of the edge attribute to verify.
-
-    Returns
-    -------
-    None
     """
     try:
         values_float = (np.array(tuple(G.edges(data=attr)))[:, 2]).astype(float)
