@@ -25,10 +25,6 @@ def citation(style: str = "bibtex") -> None:
     style
         {"apa", "bibtex", "ieee"}
         The citation format, either APA or BibTeX or IEEE.
-
-    Returns
-    -------
-    None
     """
     if style == "apa":
         msg = (
@@ -73,6 +69,7 @@ def ts(style: str = "datetime", template: str | None = None) -> str:
     Returns
     -------
     timestamp
+        The current timestamp.
     """
     if template is None:
         if style == "datetime":
@@ -115,10 +112,6 @@ def log(
     filename
         The name of the log file, without file extension. If None, set to
         `settings.log_filename` value.
-
-    Returns
-    -------
-    None
     """
     if level is None:
         level = settings.log_level
@@ -174,6 +167,7 @@ def _get_logger(name: str, filename: str) -> lg.Logger:
     Returns
     -------
     logger
+        The logger.
     """
     logger = lg.getLogger(name)
 
