@@ -142,6 +142,7 @@ def _consolidate_subdivide_geometry(geom: Polygon | MultiPolygon) -> MultiPolygo
     Returns
     -------
     geom
+        The resulting consolidated and subdivided geometry.
     """
     if not isinstance(geom, (Polygon, MultiPolygon)):  # pragma: no cover
         msg = "Geometry must be a shapely Polygon or MultiPolygon."
@@ -190,6 +191,7 @@ def _quadrat_cut_geometry(geom: Polygon | MultiPolygon, quadrat_width: float) ->
     Returns
     -------
     geom
+        The resulting split-up geometry.
     """
     # min number of dividing lines (3 produces a grid of 4 quadrat squares)
     min_num = 3
@@ -394,8 +396,8 @@ def bbox_from_point(
     EARTH_RADIUS_M = 6_371_009  # meters
     lat, lon = point
 
-    delta_lat = (dist / EARTH_RADIUS_M) * (180 / np.pi)
-    delta_lon = (dist / EARTH_RADIUS_M) * (180 / np.pi) / np.cos(lat * np.pi / 180)
+    delta_lat = np.rad2deg(dist / EARTH_RADIUS_M)
+    delta_lon = np.rad2deg(dist / EARTH_RADIUS_M) / np.cos(np.deg2rad(lat))
     top = lat + delta_lat
     bottom = lat - delta_lat
     right = lon + delta_lon
@@ -429,6 +431,7 @@ def bbox_to_poly(bbox: tuple[float, float, float, float]) -> Polygon:
     Returns
     -------
     polygon
+        The resulting bounding box polygon.
     """
     left, bottom, right, top = bbox
     return Polygon([(left, bottom), (right, bottom), (right, top), (left, top)])
